Index: inc/class-support-compat.php
===================================================================
--- inc/class-support-compat.php	(revision 4204)
+++ inc/class-support-compat.php	(working copy)
@@ -41,42 +41,66 @@
 		if ( isset( $query_vars['feed'] ) && isset( $query_vars['wporg_user_login'] ) ) {
 			if ( isset( $query_vars['bbp_view'] ) && in_array( $query_vars['bbp_view'], array( 'plugin-committer' ) ) ) {
 				$this->query = $query_vars;
-				add_filter( 'bbp_get_view_query_args', array( $this, 'get_view_query_args_for_feed' ), 10, 2 );
 
-				// Override bbPress topic pubDate handling to show topic time and not last active time
-				add_filter( 'get_post_metadata', array( $this, 'topic_pubdate_correction_for_feed' ), 10, 4 );
+				// Show plugin committer name in feed title.
+				add_filter( 'bloginfo_rss', array( $this, 'get_title_for_feed' ), 10, 2 );
+
+				// Immediately show feed.
+				$this->feed_trap();
 			}
 		}
 		return $query_vars;
 	}
 
-	public function topic_pubdate_correction_for_feed( $value, $object_id, $meta_key, $single ) {
-		// We only care about _bbp_last_active_time in this particular context
-		if( $meta_key == '_bbp_last_active_time' ) {
-			$value = get_post_time( 'Y-m-d H:i:s', true, $object_id );
-		}
-		return $value;
-	}
-
-	public function get_view_query_args_for_feed( $retval, $view ) {
+	/**
+	 * Display topics and replies in compat view feed.
+	 */
+	public function feed_trap() {
 		switch( $this->query['bbp_view'] ) {
 			case 'plugin-committer' :
-				return array(
-					'post_parent__in' => array( Plugin::PLUGINS_FORUM_ID, Plugin::REVIEWS_FORUM_ID ),
-					'post_status'     => 'publish',
-					'tax_query'       => array( array(
-						'taxonomy'    => 'topic-plugin',
-						'field'       => 'slug',
-						'terms'       => $this->get_plugin_slugs_by_committer( $this->query['wporg_user_login'] ),
-					) ),
-					'show_stickies'   => false,
-					'orderby'         => 'ID',
+				$the_query = array(
+					'feed'           => true,
+					'post_status'    => array( bbp_get_public_status_id(), bbp_get_closed_status_id() ),
+					'posts_per_page' => bbp_get_replies_per_rss_page(),
+					'order'          => 'DESC',
+					'meta_query'     => array(
+						array(
+							'key'     => '_wporg_compat',
+							'value'   => 'plugin',
+						),
+						array(
+							'key'     => '_wporg_compat_slug',
+							'value'   => $this->get_plugin_slugs_by_committer( $this->query['wporg_user_login'] ),
+							'compare' => 'IN',
+						),
+					),
 				);
 				break;
 		}
-		return $retval;
+
+		// Output the feed.
+		bbp_display_replies_feed_rss2( $the_query );
 	}
 
+	/**
+	 * Display view name in its feed title.
+	 *
+	 * @param string $title Title of the site.
+	 * @param string $type  Type of $title to filter.
+	 * @return string $title Filtered title if $type is 'name', default original.
+	 */
+	public function get_title_for_feed( $title, $type ) {
+		if ( 'name' == $type ) {
+			switch( $this->query['bbp_view'] ) {
+				case 'plugin-committer' :
+					$title .= ' &#187; ' . convert_chars( sprintf( __( 'Plugin Committer &raquo; %s', 'wporg-forums' ), $this->query['wporg_user_login'] ) );
+					break;
+			}
+		}
+
+		return $title;
+	}
+
 	public function parse_query() {
 		$user_login = get_query_var( 'wporg_user_login' );
 		$view = get_query_var( 'bbp_view' );

Index: inc/class-directory-compat.php
===================================================================
--- inc/class-directory-compat.php	(revision 4204)
+++ inc/class-directory-compat.php	(working copy)
@@ -47,6 +47,9 @@
 			// before subscriptions go out for `bbp_new_topic` at priority 10.
 			add_action( 'bbp_new_topic', array( $this, 'new_topic' ), 9, 4 );
 
+			// Always check if reply needs compat meta fields
+			add_action( 'bbp_new_reply', array( $this, 'new_reply' ), 9, 7 );
+
 			// Remove new topic form at the bottom of reviews forum.
 			add_filter( 'bbp_get_template_part', array( $this, 'noop_reviews_forum_form_topic' ), 10, 3 );
 		}
@@ -602,7 +605,7 @@
 	}
 
 	/**
 	 * Set the compat taxonomy on a topic if that data is provided on new post.
 	 *
 	 * @param int $topic_id The topic id
 	 * @param int $forum_id The forum id
@@ -619,12 +622,41 @@
 			$object = $this->get_object( $_POST['wporg_compat_slug'] );
 
 			if ( ! empty( $object ) ) {
+				// Set compat taxonomy term
 				wp_set_object_terms( $topic_id, $this->slug(), $this->taxonomy(), false );
+
+				// Set compat meta fields
+				update_post_meta( $topic_id, '_wporg_compat',      $this->compat() );
+				update_post_meta( $topic_id, '_wporg_compat_slug', $this->slug()   );
 			}
 		}
 	}
 
 	/**
+	 * Set the compat meta fields on a new reply if parent topic has them.
+	 *
+	 * @param int $reply_id The reply id
+	 * @param int $topic_id The topic id
+	 * @param int $forum_id The forum id
+	 * @param int|array $anonymous_data 0 or anonymous author data
+	 * @param int $reply_author The reply author id
+	 * @param bool $deprecated
+	 * @param int $reply_to The reply id of replied that is replied to.
+	 */
+	public function new_reply( $reply_id, $topic_id, $forum_id, $anonymous_data, $reply_author, $deprecated, $reply_to ) {
+		// Check if parent topic has compat meta fields
+		if (
+			$compat = get_post_meta( $topic_id, '_wporg_compat', true )
+			&&
+			$slug = get_post_meta( $topic_id, '_wporg_compat_slug', true )
+		) {
+			// Set compat meta fields
+			update_post_meta( $reply_id, '_wporg_compat',      $compat );
+			update_post_meta( $reply_id, '_wporg_compat_slug', $slug   );
+		}
+	}
+
+	/**
 	 * Set up and cache the plugin or theme details.
 	 *
 	 * @param string $slug The object slug
@@ -602,7 +605,7 @@
 
 	/**
-	 * Set the compat taxonomy on a topic if that data is provided on new post.
+	 * Set the compat taxonomy and meta fields on a topic if that data is provided on new post.
 	 *
 	 * @param int $topic_id The topic id